@@ -6,7 +6,10 @@ library(modeltime)
 library(modeltime.ensemble)
 library(modeltime.resample)
 
+# Model dependencies
 library(xgboost)
+library(earth)
+library(glmnet)
 
 # Core Packages
 library(tidyverse)
