@@ -1,3 +1,4 @@
+context("USED TO SET UP MODELS FOR TESTS")
 context("TEST: ensemble_average()")
 
 library(testthat)
@@ -13,11 +14,57 @@ library(tidyverse)
 library(timetk)
 library(lubridate)
 
+wflw_fit_arima <- workflow() %>%
+    add_model(
+        spec = arima_reg(seasonal_period = 12) %>% set_engine("auto_arima")
+    ) %>%
+    add_recipe(
+        recipe = recipe(value ~ date, data = training(m750_splits))
+    ) %>%
+    fit(training(m750_splits))
+
+wflw_fit_prophet <- workflow() %>%
+    add_model(
+        spec = prophet_reg() %>% set_engine("prophet")
+    ) %>%
+    add_recipe(
+        recipe = recipe(value ~ date, data = training(m750_splits))
+    ) %>%
+    fit(training(m750_splits))
+
+rec_glmnet <- recipe(value ~ date, data = training(m750_splits)) %>%
+    step_timeseries_signature(date) %>%
+    step_rm(matches("(iso$)|(xts$)|(am.pm)|(hour$)|(minute)|(second)")) %>%
+    step_zv(all_predictors()) %>%
+    step_normalize(all_numeric_predictors()) %>%
+    step_dummy(all_nominal_predictors(), one_hot = TRUE) %>%
+    step_rm(date)
+
+rec_glmnet %>% prep() %>% juice() %>% glimpse()
+
+
+wflw_fit_glmnet <- workflow() %>%
+    add_model(
+        spec = linear_reg(penalty = 0.1) %>% set_engine("glmnet")
+    ) %>%
+    add_recipe(
+        recipe = rec_glmnet
+    ) %>%
+    fit(training(m750_splits))
+
+m750_models <- modeltime_table(
+    wflw_fit_arima,
+    wflw_fit_prophet,
+    wflw_fit_glmnet
+)
+
 # TEST ENSEMBLE AVERAGE ----
 
 # Median ----
 test_that("ensemble_average(type = 'median')", {
 
+    testthat::skip_on_cran()
+
     ensemble_fit_median <- m750_models %>%
         ensemble_average(type = "median")
 
@@ -77,7 +124,11 @@ test_that("ensemble_average(type = 'median')", {
 
     # Refit
     refit_tbl <- calibration_tbl %>%
-        modeltime_refit(m750)
+        modeltime_refit(m750, control = control_refit())
+
+    # Refit in Parallel ----
+    refit_tbl <- calibration_tbl %>%
+        modeltime_refit(m750, control = control_refit(verbose = TRUE, allow_par = TRUE, cores = 2, packages = "modeltime.ensemble"))
 
     training_results_tbl <- refit_tbl %>%
         pluck(".model", 1, "model_tbl", ".model", 1, "fit", "fit", "fit", "data")
